@@ -1,6 +1,6 @@
 /*
   zip_set_file_compression.c -- set compression for file in archive
-  Copyright (C) 2012-2017 Dieter Baron and Thomas Klausner
+  Copyright (C) 2012-2021 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
   The authors can be contacted at <libzip@nih.at>
@@ -17,7 +17,7 @@
   3. The names of the authors may not be used to endorse or promote
      products derived from this software without specific prior
      written permission.
- 
+
   THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS
   OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -36,57 +36,56 @@
 
 
 ZIP_EXTERN int
-zip_set_file_compression(zip_t *za, zip_uint64_t idx, zip_int32_t method, zip_uint32_t flags)
-{
+zip_set_file_compression(zip_t *za, zip_uint64_t idx, zip_int32_t method, zip_uint32_t flags) {
     zip_entry_t *e;
     zip_int32_t old_method;
 
-    if (idx >= za->nentry || flags > 9) {
-	zip_error_set(&za->error, ZIP_ER_INVAL, 0);
-	return -1;
+    if (idx >= za->nentry) {
+        zip_error_set(&za->error, ZIP_ER_INVAL, 0);
+        return -1;
     }
 
     if (ZIP_IS_RDONLY(za)) {
-	zip_error_set(&za->error, ZIP_ER_RDONLY, 0);
-	return -1;
+        zip_error_set(&za->error, ZIP_ER_RDONLY, 0);
+        return -1;
     }
 
     if (!zip_compression_method_supported(method, true)) {
-	zip_error_set(&za->error, ZIP_ER_COMPNOTSUPP, 0);
-	return -1;
+        zip_error_set(&za->error, ZIP_ER_COMPNOTSUPP, 0);
+        return -1;
     }
 
-    e = za->entry+idx;
-    
+    e = za->entry + idx;
+
     old_method = (e->orig == NULL ? ZIP_CM_DEFAULT : e->orig->comp_method);
-    
+
     /* TODO: do we want to recompress if level is set? Only if it's
      * different than what bit flags tell us, but those are not
      * defined for all compression methods, or not directly mappable
      * to levels */
-    
+
     if (method == old_method) {
-	if (e->changes) {
-	    e->changes->changed &= ~ZIP_DIRENT_COMP_METHOD;
-	    e->changes->compression_level = 0;
-	    if (e->changes->changed == 0) {
-		_zip_dirent_free(e->changes);
-		e->changes = NULL;
-	    }
-	}
+        if (e->changes) {
+            e->changes->changed &= ~ZIP_DIRENT_COMP_METHOD;
+            e->changes->compression_level = 0;
+            if (e->changes->changed == 0) {
+                _zip_dirent_free(e->changes);
+                e->changes = NULL;
+            }
+        }
     }
     else {
         if (e->changes == NULL) {
-            if ((e->changes=_zip_dirent_clone(e->orig)) == NULL) {
+            if ((e->changes = _zip_dirent_clone(e->orig)) == NULL) {
                 zip_error_set(&za->error, ZIP_ER_MEMORY, 0);
                 return -1;
             }
         }
 
         e->changes->comp_method = method;
-	e->changes->compression_level = (zip_uint16_t)flags;
+        e->changes->compression_level = (zip_uint16_t)flags;
         e->changes->changed |= ZIP_DIRENT_COMP_METHOD;
     }
-    
+
     return 0;
 }
